using Nirvana.Common;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Waste.Application
{
    /// <summary>
    /// 苏州设备对接平台
    /// </summary>
    public interface ISuZhouService
    {
        /// <summary>
        /// Hello接口GET测试
        /// </summary>
        /// <param name="greet"></param>
        /// <returns></returns>
        Task<ResultInfo> GetHelloAsync(string greet);
        /// <summary>
        /// Hello接口Post测试
        /// </summary>
        /// <param name="greet"></param>
        /// <returns></returns>
        Task<ResultInfo> PostHelloAsync(string greet);
        /// <summary>
        /// 分页查询当前账号下存在的地产区域数据
        /// </summary>
        /// <param name="page"></param>
        /// <param name="size"></param>
        /// <param name="search"></param>
        /// <returns></returns>
        Task<ResultInfo> GetEstatesAsync(int page = 1, int size = 10, string search = "");
        /// <summary>
        /// 添加地产区域信息
        /// </summary>
        /// <param name="estatesC2SDto"></param>
        /// <returns></returns>
        Task<ResultInfo> PostEstatesAsync(EstatesC2SDto estatesC2SDto);
        /// <summary>
        /// 查询地产区域信息
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<ResultInfo> GetEstatesByIdAsync(string id);
        /// <summary>
        /// 向服务端推送测试用垃圾采集数据
        /// </summary>
        /// <param name="garbageC2SDto"></param>
        /// <returns></returns>
        Task<ResultInfo> PostGarbagesAsync(GarbageC2SDto garbageC2SDto);

        /// <summary>
        /// 向服务端推送测试用垃圾采集数据
        /// </summary>
        /// <param name="garbageC2SDto"></param>
        /// <returns></returns>
        Task<ResultInfo> PostGarbagesAsync(GarbagePltC2SDto garbageC2SDto);
        /// <summary>
        /// 删除地产区域
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<ResultInfo> DeleteEstates(string id);

        /// <summary>
        /// 删除采集点
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<ResultInfo> DeleteCollect(string id);

        /// <summary>
        /// 添加采集点
        /// </summary>
        /// <param name="estatesC2SDto"></param>
        /// <returns></returns>
        Task<ResultInfo> PostCollectAsync(CollectC2SDto estatesC2SDto);

        /// <summary>
        /// 获取时间戳
        /// </summary>
        /// <returns></returns>
        int GetTimestamp();

        /// <summary>
        /// 获取随机数
        /// </summary>
        /// <returns></returns>
         int GetNonce();

        /// <summary>
        /// 获取UTC时间戳
        /// </summary>
        /// <returns></returns>
        int GetUTCTimestamp();
        /// <summary>
        /// 获取签名
        /// </summary>
        /// <param name="secret"></param>
        /// <param name="dataparams"></param>
        /// <returns></returns>
        string GetUserApiSign(string secret, params string[] dataparams);
    }
}
